## `citros service`

This section contain all service related functionality

### start
will start a resfull api server that will expose data/report

### stop 
stop the resfull api server

### status
show the status of the resfull api server
